==> haskell-expiring-cache-map-0.0.6.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: expiring-cache-map
version: 0.0.6.1
id: expiring-cache-map-0.0.6.1-4SREgqLGIoAFltC1JZGW3l
key: expiring-cache-map-0.0.6.1-4SREgqLGIoAFltC1JZGW3l
license: BSD3
copyright: (c) 2014 Edward L. Blake
maintainer: edwardlblake@gmail.com
homepage: https://github.com/elblake/expiring-cache-map
synopsis: General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.
category: Caching
author: Edward L. Blake
exposed: True
exposed-modules:
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types
abi: eb41dfdf714a25f198f2c32fb30644ec
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/expiring-cache-map-0.0.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/expiring-cache-map-0.0.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/expiring-cache-map-0.0.6.1
hs-libraries: HSexpiring-cache-map-0.0.6.1-4SREgqLGIoAFltC1JZGW3l
depends:
    base-4.9.0.0 containers-0.5.7.1
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    unordered-containers-0.2.7.2-fKwgRekRaR5O5PqcoNK7l
haddock-interfaces: /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock
haddock-html: /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-expiring-cache-map-0.0.6.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: expiring-cache-map
version: 0.0.6.1
id: expiring-cache-map-0.0.6.1-FzLFuUQvfKV9woPBwUaBdT
key: expiring-cache-map-0.0.6.1-FzLFuUQvfKV9woPBwUaBdT
license: BSD3
copyright: (c) 2014 Edward L. Blake
maintainer: edwardlblake@gmail.com
homepage: https://github.com/elblake/expiring-cache-map
synopsis: General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.
category: Caching
author: Edward L. Blake
exposed: True
exposed-modules:
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types
abi: 9f9ee606c03d20cb07104f71fc360112
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/expiring-cache-map-0.0.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/expiring-cache-map-0.0.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/expiring-cache-map-0.0.6.1
hs-libraries: HSexpiring-cache-map-0.0.6.1-FzLFuUQvfKV9woPBwUaBdT
depends:
    base-4.9.0.0 containers-0.5.7.1
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
haddock-interfaces: /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock
haddock-html: /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
